@@ -8,13 +8,8 @@ use JSON::XS;
 use MIME::Base64;
 use Time::HiRes qw( ualarm usleep );
 
-sub reaper {
-warn "Reaper...";
-  my $waitpid = wait;
-warn "$$: waitpid:$waitpid";
-  $SIG{CHLD} = \&reaper;
-}
-$SIG{CHLD} = 'IGNORE';
+# If you have a better idea, please let me know:
+local $SIG{CHLD} = 'IGNORE';
 
 
 #==============================================================================
@@ -74,7 +69,7 @@ sub child_loop
     $credentials = join '|', ( $s->{username}, $s->{password} );
   }# end if()
   
-  LOOP: while( 1 )
+  LOOP: while( $s->{running} )
   {
     eval {
       $s->{sock} = $s->connect( $s->{event}, $credentials )
@@ -116,7 +111,7 @@ sub child_loop
       {
         foreach my $msg ( grep { $_ } split /\n\n/, $buffer )
         {
-          $s->{callback}->( $s->{json}->decode( decode_base64( $msg ) ) );
+          $s->call_callback( $s->{callback}, $s->{json}->decode( decode_base64( $msg ) ) );
         }# end foreach()
       }# end if()
     }# end if()
@@ -124,6 +119,16 @@ sub child_loop
 }# end child_loop()
 
 
+#==============================================================================
+sub call_callback
+{
+  my ($s, $callback, $event) = @_;
+  
+  local $::SUBSCRIBER = $s;
+  $callback->( $event );
+}# end call_callback()
+
+
 #==============================================================================
 sub running
 {
@@ -170,3 +175,70 @@ sub DESTROY
 
 1;# return true:
 
+=pod
+
+=head1 NAME
+
+Event::Lite::Subscriber - Event listener with callback
+
+=head1 SYNOPSIS
+
+  use Event::Lite::Subscriber;
+  
+  my $subscriber = Event::Lite::Subscriber->new(
+    address => 'your.server.com',
+    port    => 34343,
+  );
+  
+  $subscriber->subscribe(
+    event     => 'name_of_the_event_to_subscribe_to',
+    callback  => sub {
+      my $event = shift;
+      # This code is executed in a separate process.
+      warn "The event named '$event->{event}' has happened";
+    },
+    
+    # The username/password are only necessary if your server requires them:
+    username  => 'admin',
+    password  => 'swordfish',
+  );
+  
+  # Do stuff...
+  calculate_pi() while 1;
+  
+  # Finally:
+  $subscriber->stop();
+
+=head1 DESCRIPTION
+
+C<Event::Lite::Subscriber> provides low-level (yet simple) access to events that
+are broadcast by an L<Event::Lite::Publisher> through a L<Event::Lite::Server>.
+
+B<NOTE:> The subscriber object runs its event loop in a separate process.  That means your
+callback code won't have any effect over variables in the parent process.  You
+also cannot share database handles, open sockets or file handles between the
+parent process and your callback code.
+
+If this is a limitation you just can't deal with, check out L<Event::Lite::Subscriber::NoFork>
+because it does not have the same issue (because it does not fork).
+
+=head1 SUPPORT
+
+Visit L<http://www.devstack.com/contact/> or email the author at <jdrago_999@yahoo.com>
+
+Commercial support and installation is available.
+
+=head1 AUTHOR
+
+John Drago <jdrago_999@yahoo.com>
+ 
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2008 by John Drago
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.10.0 or,
+at your option, any later version of Perl 5 you may have available.
+
+=cut
+
